Attribute VB_Name = "DSO_IO"
'This module contains all the functions which use the printer port
'Printer Port control bit descriptions
' C0, C1 and C3 are low true;  C2 is high true
' C0..C2 select the basic function
' C3 is the  "clock" or strobe
'
' The following are for the DSO_LA only - not the SBLA!
' Main Functions
'  0 = not used
'  1 = SysReset-PL
'  2 = SysEnable-PL
'  3 = subFunction Select
'  4 = ReadClock-PL
'  5 = subFunction 0..7 strobe
'  6 = not used
'  7 = not used
'
' subFunctions
'  bits 0..3
'     0 = CmpLatch-Ch0-PL
'     1 = CmpLatch-Ch1-PL
'     2 = CmpLatch-Ch2-PL
'     3 = CmpLatch-Ch3-PL
'     4 = not used
'     5 = not used
'     6 = TrigChEna-PL
'     7 = TrigChState-PL
'     8 = Read-Ch0-L
'     9 = Read-Ch1-L
'    10 = Read-Ch2-L
'    11 = Read-Ch3-L
'    12 = Read-Ch4-L
'    13 = Read-Ch5-L
'    14 = ReadLowTrigAddr-L
'    15 = ReadHighTrigAddr-L
'  bits 4..6
'     Time Base Select
'     0 = ReadClock-PL
'     1..7 = Sample Clock
'  bit 7 = not used

Public Sub CtrlBit(BitNbr, State)
' set/clear a control bit
   I = 2 ^ BitNbr             ' create mask for bit
   If State = 0 Then
      iControlPort = iControlPort And Not I
   Else
      iControlPort = iControlPort Or I
   End If
   WrControl (iControlPort)
End Sub ' CtrlBit

Public Sub ReadCh(Channel As Integer)
' read the channel - put the data in bDataArray(0,0...)
   Dim Addr As Long
   Dim I As Integer
   Dim J As Integer
   Dim K As Integer
   Dim TimeBaseIndexSave As Integer
   
' reset the system - including the address generator - also clears pre/post trigger values
' NOTE: same for SBLA
   WrControl SYSRESET
   WrControl SYSRESET + CONTROL_STROBE
   WrControl SYSRESET
   
   If SBLA = 0 Then
      TimeBaseIndexSave = iTimeBaseIndex  ' save value
      iTimeBaseIndex = 0         ' set for ReadClock
      SubFunction Channel        ' select the channel
' read each byte
      K = 0                      ' set up for inversion test
      J = Channel - SUB_READ_0 + 1
      If iBoardType(J) = AD_BOARD And Invert(J) = 1 Then K = 1
   
      For Addr = 1 To MAX_SAMPLES - 1
         WrControl READSUB Or READ_ENABLE_MASK ' set control port to read
         WrControl READSUB Or READ_ENABLE_MASK Or CONTROL_STROBE  ' advances address counter
         J = Inp(PortAddr)
         If K Then J = 255 - J
         bDataArray(0, Addr) = J
      Next Addr
      WrControl READSUB Or READ_ENABLE_MASK ' set control port to read
      WrControl READSUB Or READ_ENABLE_MASK Or CONTROL_STROBE  ' advances address counter
      bDataArray(0, 0) = Inp(PortAddr)
      WrControl READSUB          ' disable read
      iTimeBaseIndex = TimeBaseIndexSave  ' restore
   Else
' read each byte
      WrControl (READ_ENABLE_MASK Or Channel) ' enable read
      For Addr = 0 To MAX_SAMPLES - 1
         J = Inp(PortAddr)
         bDataArray(0, Addr) = J
         WrControl READ_ENABLE_MASK Or Channel Or CONTROL_STROBE  ' advances address counter
         WrControl READ_ENABLE_MASK Or Channel
      Next Addr
      WrControl (0)   ' remove read enable
   End If
End Sub ' ReadCh

Public Function ReadData()
' read data from the Data port
   WrControl (READ_ENABLE_MASK Or READSUB) ' enable read
' now put the data on the bus
   WrControl (READ_ENABLE_MASK Or READSUB Or CONTROL_STROBE)
   ReadData = Inp(PortAddr)
   WrControl (READSUB)   ' remove read enable
End Function ' ReadData

Public Sub ReadStatus()
' read from the status port
   I = Inp(PortAddr + STATUS_OFFSET)
   iTrigLatch = (I And 16) \ 16
   iSampleClkEna = (I And 32) \ 32
   iPreTrigDone = (I And 64) \ 64
   iStatusBit7 = (I And 128) \ 128
End Sub ' ReadStatus

Public Function ReadTrigAddr()
' read the trigger address
   Dim LowAddr As Long
   Dim HighAddr As Long
   
   If SBLA = 0 Then
      SubFunction SUB_READ_LOW_TRIG_ADR
      LowAddr = ReadData And &HFF           ' make sure upper bits are 0
      SubFunction SUB_READ_HIGH_TRIG_ADR
      HighAddr = ReadData
   Else
      WrControl (READ_ENABLE_MASK Or SBLA_READ_TRIG_ADDR_LOW) ' enable read
      LowAddr = Inp(PortAddr) And &HFF   ' make sure upper bits are 0
      WrControl (READ_ENABLE_MASK Or SBLA_READ_TRIG_ADDR_HIGH) ' enable read
      HighAddr = Inp(PortAddr) And &HFF   ' make sure upper bits are 0
      WrControl (0)   ' remove read enable
   End If
   
   ReadTrigAddr = LowAddr + (HighAddr * 256)
   ReadTrigAddr = ReadTrigAddr * 2          ' adjust for no address bit 0
End Function ' ReadTrigAddr

Public Sub SubFunction(iSub As Integer)
   WrData (iTimeBaseIndex * 16) Or iSub ' put subfunction on data bus
   WrControl SUBSELECT     ' select sub function
   WrControl SUBSELECT + CONTROL_STROBE ' latch it
   WrControl SUBSELECT     ' remove latch
End Sub ' SubFunction

Public Sub WrControl(Value As Integer)
' write a value to the Control port
   iControlPort = Value          ' save the value
   I = iControlPort Xor CONTROL_PORT_MASK
   If SBLA > 0 Then I = I Xor CONTROL_STROBE        ' adjust for high true strobe
   Out PortAddr + CONTROL_OFFSET, I
End Sub ' WrControl

Public Sub WrData(Value As Integer)
' write a value to the Data port
   I = iControlPort And Not READ_ENABLE_MASK
   WrControl (I)          ' set control port to write
   iDataPort = Value
   Out PortAddr, iDataPort
End Sub ' WrData

Public Sub WrSub(ByVal iSub As Integer, Value As Byte)
   SubFunction iSub
   WrData (Value)
   WrControl WRITESUB
   WrControl WRITESUB + CONTROL_STROBE
   WrControl WRITESUB
End Sub ' WrSub
