Attribute VB_Name = "DSO_Data"
'Control signal descriptions for programming the DSO/LA
'    L = level,        P = pulse
'Data Port: Base

   #Const doDebug = 1
   Global Const VERSION = 0.1

'Global Constants
   Global Const INI_FILE = 1           ' channel for INI file
   Global Const DATA_FILE = 2          ' channel for Data file
   Global Const DEF_INI_FILE = "dso.ini"
   Global Const BKG_RED = &H8080FF
   Global Const BKG_WHITE = &HFFFFFF
   Global Const BKG_GREY = &H8000000F
   Global Const BKG_DARKGREEN = &H8000&
   Global Const COLOR_BLACK = &H0&
   Global Const COLOR_BROWN = &H4080&
   Global Const COLOR_RED = &HFF&
   Global Const COLOR_ORANGE = &H80C0FF0
   Global Const COLOR_YELLOW = &HFFFF&
   Global Const COLOR_GREEN = &HFF00&
   Global Const COLOR_BLUE = &HFF0000
   Global Const COLOR_VIOLET = &HFFC0C0
   Global Const COLOR_GRAY = &HC0C0C0
   Global Const COLOR_WHILE = &HFFFFFF
   
'Printer Port Control Register Definitions
   Global Const CONTROL_PORT_MASK = 3  ' invert bits 0 & 1
   Global Const CONTROL_STROBE = 8     ' bit 3 is strobe
   Global Const READ_ENABLE_MASK = 32  ' bit 5: 0=Write, 1=Read
   Global Const SYSRESET = 1
   Global Const SYSENABLE = 2
   Global Const SUBSELECT = 3
   Global Const READSUB = 4
   Global Const WRITESUB = 5
' write sub functions
   Global Const SUB_TRIG_CMP_LATCH_0 = 0
   Global Const SUB_TRIG_CMP_LATCH_1 = 1
   Global Const SUB_TRIG_CMP_LATCH_2 = 2
   Global Const SUB_TRIG_CMP_LATCH_3 = 3
   Global Const SUB_TRIG_CH_ENA = 6
   Global Const SUB_TRIG_CH_STATE = 7
' read sub function
   Global Const SUB_READ_0 = 0 + 8
   Global Const SUB_READ_1 = 1 + 8
   Global Const SUB_READ_2 = 2 + 8
   Global Const SUB_READ_3 = 3 + 8
   Global Const SUB_READ_4 = 4 + 8
   Global Const SUB_READ_5 = 5 + 8
   Global Const SUB_READ_LOW_TRIG_ADR = 6 + 8
   Global Const SUB_READ_HIGH_TRIG_ADR = 7 + 8

'Printer Port Values
   Global iControlPort As Integer      ' control port value
   Global iOutputPort As Integer       ' data port value
   Global iTrigLatch As Integer
   Global iAddrClkEna As Integer
   Global iPreTrigDone As Integer
   Global iStatusBit7 As Integer

'INI File Section Name values
   Global Const GENERAL = 1
   Global Const BOARD_TYPES = 2
   Global Const CHANNELS = 3
   Global Const TIMEBASE = 4
   Global Const TRIGGER = 5
   Global Const DISPLAY = 6
   Global Const AD_CONFIG = 7

'Values for reading DSO.ini
   Global szString As String * 255     ' general string variable
   Global szParameter As String * 15   ' parameter value
   Global szIniFileName As String * 50
   Global szIniFolder As String * 50
   Global szIniDrive As String * 2

'[General]
   Global PortAddr As Integer          ' address of parallel port
   Global szRegName As String * 30

   Global Const DATA_OFFSET = 0        ' parallel port registers
   Global Const STATUS_OFFSET = 1
   Global Const CONTROL_OFFSET = 2

'[Board Types]
   Global Const MAX_BOARDS = 6
   Global Const LA_BOARD = 1
   Global Const AD_BOARD = 2
   Global Const NO_BOARD = 3
   Global iBoardType(1 To MAX_BOARDS) As Integer
   Global AD_Color(1 To MAX_BOARDS) As Long
   Global AD_Width(1 To MAX_BOARDS) As Long
   
'[Channels]
   Global szChannelName(1 To MAX_BOARDS, 0 To 7) As String * 10
   Global bLA_Use(1 To MAX_BOARDS, 0 To 7) As Byte
   Global sLA_Use As String * 8
   Global bADTrig(1 To MAX_BOARDS) As Byte
   Global iLAchannels As Integer
   Global iADchannels As Integer
   Global ChannelsChanged As Integer

'[TimeBase]
   Global Const TIME_BASE_VALS = 15
   Global rSamplePeriod(0 To TIME_BASE_VALS) As Single
   Global szSamplePeriodName(0 To TIME_BASE_VALS) As String * 10
   Global iTimeBaseIndex As Integer

'[Trigger]
   Global Const TRIG_MAX = 16
   Global Const NO_TRIG = 255
   Global Const TRIG_WINDOW = 2 ^ 13
   Global iPreTrig As Integer
   Global iPostTrig As Integer
   Global bTrig(0 To 7) As Byte

'[AD_CONFIG]
   Global Const AD_RANGE_MAX = 7
   Global AD_Range(0 To 7, 0 To 1) As Single
   Global szAD_Range(0 To AD_RANGE_MAX) As String * 10
   Global AD_RangeIndex(1 To MAX_BOARDS) As Integer
   Global AD_RangeMax As Integer
   Global AD_Yscale(1 To MAX_BOARDS) As Integer
   Global Const AD_SCALE_1 = 4
   Global AD_Yoffset(1 To MAX_BOARDS) As Integer
   

'[DISPLAY]
   Global fZoom As Single           ' zoom factor
   Global fSlide As Single          ' slide factor
   Global AD_Size As Single
   Global LA_Size As Single
   Global CursorsColor As Long
   Global CursorsWidth As Integer

' Time Grid Lines
   Global TGridLinesOn As Integer
   Global TGridLinesColor As Long
   Global TGridLinesWidth As Integer
   Global TPDvalues(1 To 27) As Single
   Global Const TPD_MIN = 0.0000001    ' 100 ns
   Global Const TPD_MAX = 0.1          ' 100 ms
   Global iTPD As Integer
   Global iTPDchange As Integer
   Global TPDtext As String * 10


'Data file variables
   Global szDataFileName As String * 50
   Global szDataFolder As String * 50
   Global szDataDrive As String * 2

' Drawing values
   Global Const X_INITIAL = 10
   Global Const Y_INITIAL = 120
   Global Const Y_INCREMENT = 10
   Global Const Y_SPACE = 40
   Global Const X_SPACE = 80
   Global Const STARTS = 0
   Global Const ENDS = 1
   Global Const WINDOW_HSX_SCALE = 4
   Global Const MIN_WINDOW = WINDOW_HSX_SCALE * 5
   Global lStartSample As Long
   Global lEndSample As Long
   Global lTotalSamples As Long

' Cursor stuff
   Global Const NBR_CURSORS = 4     ' number of "other" cursors
   Global lCursorSample(0 To NBR_CURSORS) As Long
   Global iCursorFlag(0 To NBR_CURSORS) As Integer
   Global iCursorDispType As Boolean   ' TRUE = samples, FALSE = time

   Global Const MAX_SAMPLES = 2 ^ 17   ' determined by RAM
   Global iMax_Samples As Long      ' determined by Pre & Post Trig values
   Global bDataArray(0 To MAX_BOARDS, 0 To MAX_SAMPLES - 1) As Byte
   Global iSampleNr As Long

   Global iCursorDisplay As Integer ' 0=off,  1=Ch1 is MSB,   2=Ch8 is MSB
   Global iCursorBase As Integer    ' 0 = Decimal,  1 = Hex,  2 = Octal,  3 = Binary
   Global iStop As Integer
   

'Measurement values
   Global iMeasDataBits As Integer
   Global fMeasStopBits As Integer
   Global iMeasParity As Integer
   Global iMeasMarkState As Integer
   Global iMeasMSBfirst As Single
   Global fMeasBaud As Single
   Global iMeasChannel As Integer
   Global iMeasStartCursor As Integer
   Global iMeasPresentation As Single
   Global iMeasGo As Integer

'Other files required by the program
#If doDebug Then
        ' Parallel Port
   Declare Function Inp Lib "c:\jlc\dso\vb\inpout32.Dll" Alias "Inp32" (ByVal PortAddress As Integer) As Integer
   Declare Sub Out Lib "c:\jlc\dso\vb\inpout32.Dll" Alias "Out32" (ByVal PortAddress As Integer, ByVal Value As Integer)
#Else
        ' Parallel Port
   Declare Function Inp Lib "inpout32.Dll" Alias "Inp32" (ByVal PortAddress As Integer) As Integer
   Declare Sub Out Lib "inpout32.Dll" Alias "Out32" (ByVal PortAddress As Integer, ByVal Value As Integer)
#End If

